@@ -1,7 +1,8 @@
 ;; debian-bug.el --- report a bug to Debian's bug tracking system
 
 ;; Copyright (C) 1998, 1999 Free Software Foundation, Inc.
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Peter S Galbraith <psg@debian.org>
+;; Copyright (C) 2001, 2002, 2003, 2004 Peter S Galbraith <psg@debian.org>
+;; Copyright (C) 2005, 2006, 2007 Peter S Galbraith <psg@debian.org>
 
 ;; Help texts from
 ;;  http://www.debian.org/Bugs/Developer#severities
@@ -24,10 +25,6 @@
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 ;;
-;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, write to
-;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
 ;; ----------------------------------------------------------------------------
 ;;; Commentary:
 ;;
@@ -283,6 +280,15 @@
 ;;   - Updated the list of valid tags.
 ;; V1.63 25Jul2007 Peter S Galbraith <psg@debian.org>
 ;;  - Adapt patch from Luca Capello <luca@pca.it> for bug #431091
+;; V1.64 29Aug2007 Peter S Galbraith <psg@debian.org>
+;;  - `debian-changelog-close-bug-statement' may not be bound (Closes: #440002)
+;;    Thanks to my friend Bill Wohler for finding this bug.
+;; V1.65 02Sep2007 Peter S Galbraith <psg@debian.org>
+;;  - Implement pacakge lookup on http://packages.debian.org/
+;;    See http://bugs.debian.org/87725
+;; V1.66 24Sep2007 Luca Capello <luca@pca.it>
+;;  - Add `debian-bug-get-bug-as-email-hook' and relative `run-hooks'
+;;    (Closes: #392475) 
 ;; ----------------------------------------------------------------------------
 
 ;;; Todo (Peter's list):
@@ -442,6 +448,13 @@ Otherwise, simply use the menu entry to generate it."
   :group 'debian-bug
   :type 'boolean)
 
+;; hooks
+(defcustom debian-bug-get-bug-as-email-hook nil
+  "Hook run when getting a bug through `mail-user-agent'."
+  :group 'debian-bug
+  :type 'hook)
+
+
 ;;; Internal variables:
 
 (defvar debian-bug-mail-address
@@ -694,9 +707,9 @@ Reportbug may have sent an empty report!")))
       (forward-line 1)
       (if (looking-at "^<#secure")      ;Skip over mml directives
           (forward-line 1))
-      (message "Getting package information from system...")
+      (message "Getting package information from reportbug...")
       (debian-bug-prefill-report package severity)
-      (message "Getting package information from system...done")
+      (message "Getting package information from reportbug...done")
       (if debian-bug-use-From-address
           (debian-bug--set-custom-From))
       (if debian-bug-always-CC-myself
@@ -1334,12 +1347,11 @@ Aug 10th 2001
      ["Bugs for This Package" (debian-bug-web-bugs) t]
      ["Archived Bugs for This Package" (debian-bug-web-bugs t) t]
      ["Bug Number..." (debian-bug-web-bug) t]
-     ["Package Info" (debian-bug-web-packages) t]
-;;   ("Info for This Package"
-;;    ["Stable" (debian-bug-web-package "stable") t]
-;;    ["Testing" (debian-bug-web-package "testing") t]
-;;    ["Unstable" (debian-bug-web-package "unstable") t]
-;;    )
+     ["Package search for all releases" (debian-bug-web-packages) t]
+     "-- Package Web Pages --"
+     ["Stable" (debian-bug-web-package "stable") t]
+     ["Testing" (debian-bug-web-package "testing") t]
+     ["Unstable" (debian-bug-web-package "unstable") t]
      )
     ["Customize"
      (customize-group "debian-bug") (fboundp 'customize-group)]
@@ -1548,13 +1560,13 @@ In a program, mouse location is in EVENT."
 		      (read-string "Package name: "))))
     (if (string-equal "" pkg-name)
         (message "No package name to look up")
-      (browse-url
-       (concat
-        "http://packages.debian.org/cgi-bin/search_packages.pl?keywords="
-        pkg-name
-        "&searchon=names&version=all&release=all"))
-      (message "Looking up web pages for package %s via browse-url"
-               pkg-name))))
+      (browse-url (concat "http://packages.debian.org/" pkg-name))
+;; 2007-09-02 This URL is becoming obsolete...
+;;       (concat
+;;        "http://packages.debian.org/cgi-bin/search_packages.pl?keywords="
+;;        pkg-name
+;;        "&searchon=names&version=all&release=all")
+      (message "Looking up web pages for package %s via browse-url" pkg-name))))
 
 (defvar debian-bug-archive-alist
   '(("stable") ("testing") ("unstable"))
@@ -1585,11 +1597,8 @@ In a program, mouse location is in EVENT."
                                  debian-bug-archive-alist nil t nil)))
       (if (string-equal "" archive)
           (message "No archive name to look up")
-        (browse-url
-         (concat
-          "http://packages.debian.org/cgi-bin/search_packages.pl?keywords="
-          pkg-name
-          "&searchon=names&release=all&version=" archive))
+        (browse-url (format "http://packages.debian.org/%s/%s"
+                            archive pkg-name))
         (message "Looking up %s web page for package %s via browse-url"
                  archive pkg-name)))))
 
@@ -1708,6 +1717,7 @@ If SUBMENU is t, then check for current sexp submenu only."
                                     (gnus-alive-p))))
                      (error "Please start `gnus' (or `gnus-slave') first"))
                  (debian-bug-prompt-bug-number "Bug number to fetch")))
+  (run-hooks 'debian-bug-get-bug-as-email-hook)
   (cond
    ((and (eq mail-user-agent 'mh-e-user-agent)
          (featurep 'mh-inc))
@@ -1772,6 +1782,7 @@ Only decodes if `rfc2047-decode-string' is available."
       (rfc2047-decode-string string)
     string))
 
+(defvar debian-changelog-close-bug-statement)
 (defun debian-bug-build-bug-menu (package)
   "Build a menu listing the bugs for PACKAGE."
   (setq debian-bug-alist nil
@@ -1842,7 +1853,9 @@ Only decodes if `rfc2047-decode-string' is available."
                                  (match-string 1))
                                 " " (debian-bug--rris
 				     "%s" bugnumber
-				     debian-changelog-close-bug-statement))))
+				     (if (boundp 'debian-changelog-close-bug-statement)
+					 debian-changelog-close-bug-statement
+				       "(Closes: #%s)")))))
                 (setq bug-open-alist
                       (cons
                        (list bugnumber shortdescription) bug-open-alist)))
