@@ -7,7 +7,7 @@
 ;; Maintainer: Peter S Galbraith <psg@debian.org>
 ;; Created: 29 Nov 2001
 ;; Version: 0.9
-;; X-RCS: $Id: debian-control-mode.el,v 1.9 2005/11/23 02:37:02 psg Exp $
+;; X-RCS: $Id: debian-control-mode.el,v 1.12 2007-10-18 11:45:37 kibi-guest Exp $
 ;; Keywords: convenience
 
 ;; This file is free software; you can redistribute it and/or modify
@@ -32,6 +32,15 @@
 
 ;;; Change Log:
 
+;; V1.1 (2007-10-18)  Cyril Brulebois <cyril.brulebois@enst-bretagne.fr>
+;; - Renamed "XS-Vcs-*" fields into "Vcs-*", officially supported since
+;;   dpkg/1.14.7.
+
+;; V1.0 (2007-10-01)  Cyril Brulebois <cyril.brulebois@enst-bretagne.fr>
+;; - Add "Homepage" field to source fields.
+;; - Add "XS-Vcs-*" fields to source fields, patch contributed by
+;;   Rafael Laboissiere <rafael@debian.org> (Closes: #422491).
+
 ;; V0.9 (2005-11-22)  Peter S Galbraith <psg@debian.org>
 ;; - Make # the comment character. (Closes: #339868)
 
@@ -149,9 +158,19 @@
 
 (defvar debian-control-mode-package-name-keymap (make-sparse-keymap))
 
+;; An uptodate list can be found at:
+;;   http://svn.debian.org/wsvn/qa/trunk/pts/www/bin/common.py?op=file
+(defvar debian-control-vcs-names
+  '("Arch" "Bzr" "Cvs" "Darcs" "Git" "Hg" "Mtn" "Svn")
+  "Valid VCS names for the Vcs-* field.")
+
 (defvar debian-control-source-fields
+  (append
   '("Section" "Priority" "Maintainer" "Build-Depends" "Build-Depends-Indep"
-    "Build-Conflicts" "Build-Conflicts-Indep" "Standards-Version" "Uploaders")
+     "Build-Conflicts" "Build-Conflicts-Indep" "Standards-Version" "Uploaders"
+     "Homepage" "Vcs-Browser")
+   (mapcar (lambda (elt) (concat "Vcs-" elt))
+           debian-control-vcs-names))
   "Valid source package field names, collected from several policy sections.")
 
 (defvar debian-control-binary-fields
